# Arguments

The `args` setting allows for the configuration of build arguments. It consists of a list of
name-value pairs, with each name-value pair defining one argument and its value.

:::{code-block} yaml
args:
  - name:   # The environment variable name
    value:  # The environment variable value
:::
